==> mediawiki-1.25.3-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/Gadgets/Gadgets.alias.php <==
<?php
/**
 * Aliases for Special:Gadgets
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Gadgets' => array( 'Gadgets' ),
);

/** Afrikaans (Afrikaans) */
$specialPageAliases['af'] = array(
	'Gadgets' => array( 'Geriewe' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Gadgets' => array( 'إضافات' ),
);

/** Egyptian Spoken Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Gadgets' => array( 'ادوات' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'Gadgets' => array( 'গেজেটসমূহ' ),
);

/** Avaric (авар) */
$specialPageAliases['av'] = array(
	'Gadgets' => array( 'Гаджеты' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'Gadgets' => array( 'Джаджи' ),
);

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = array(
	'Gadgets' => array( 'وسایل_ئان' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'Gadgets' => array( 'Pakakas' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'Gadgets' => array( 'Bitrakoù' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'Gadgets' => array( 'Dodaci' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'Gadgets' => array( 'Гаджеташ' ),
);

/** Sorani Kurdish (کوردی) */
$specialPageAliases['ckb'] = array(
	'Gadgets' => array( 'ئامرازەکان' ),
);

/** Czech (čeština) */
$specialPageAliases['cs'] = array(
	'Gadgets' => array( 'Udělátka' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Gadgets' => array( 'Helferlein' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Gadgets' => array( 'Gadgeti' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'Gadgets' => array( 'Gadgety' ),
);

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = array(
	'Gadgets' => array( 'Εργαλεία', 'Προσαρτήματα' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Gadgets' => array( 'Aldonaĵoj' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Gadgets' => array( 'Accesorios', 'Artilugios' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Gadgets' => array( 'Tööriistad' ),
);

/** Basque (euskara) */
$specialPageAliases['eu'] = array(
	'Gadgets' => array( 'Gadgetak' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Gadgets' => array( 'ابزارها' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'Gadgets' => array( 'Pienoisohjelmat' ),
);

/** Franco-Provençal (arpetan) */
$specialPageAliases['frp'] = array(
	'Gadgets' => array( 'Outils' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Gadgets' => array( 'Trebellos' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'Gadgets' => array( 'Hälferli' ),
);

/** Hawaiian (Hawai`i) */
$specialPageAliases['haw'] = array(
	'Gadgets' => array( 'Hāmeʻa', 'Hamea' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Gadgets' => array( 'גאדג\'טים', 'סקריפטים' ),
);

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = array(
	'Gadgets' => array( 'उपकरण', 'गैजेट' ),
);

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = array(
	'Gadgets' => array( 'Dodaci' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'Gadgets' => array( 'Specialne_funkcije' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Gadgets' => array( 'Gajèt' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Gadgets' => array( 'Segédeszközök' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'Gadgets' => array( 'Gadgetes' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Gadgets' => array( 'Alat', 'Gadget' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'Gadgets' => array( 'Accessori' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Gadgets' => array( 'ガジェット' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Gadgets' => array( '소도구', '가젯' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'Gadgets' => array( 'Instrumenticos' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'Gadgets' => array( 'Gadgeten' ),
);

/** لوری (لوری) */
$specialPageAliases['lrc'] = array(
	'Gadgets' => array( 'گجتیا' ),
);

/** Minangkabau (Baso Minangkabau) */
$specialPageAliases['min'] = array(
	'Gadgets' => array( 'Pakakeh' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Gadgets' => array( 'Алатки' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Gadgets' => array( 'കൂട' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'Gadgets' => array( 'सुविधा' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'Gadgets' => array( 'Gajet' ),
);

/** Maltese (Malti) */
$specialPageAliases['mt'] = array(
	'Gadgets' => array( 'Aġġeġġi', 'Aċċessorji' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'Gadgets' => array( 'Tilleggsfunksjoner' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'Gadgets' => array( 'Technies_spul' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'Gadgets' => array( 'Extensies' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'Gadgets' => array( 'Tilleggsfunksjonar' ),
);

/** Occitan (occitan) */
$specialPageAliases['oc'] = array(
	'Gadgets' => array( 'Gadgèts' ),
);

/** Punjabi (ਪੰਜਾਬੀ) */
$specialPageAliases['pa'] = array(
	'Gadgets' => array( 'ਛੋਟੇ_ਸੰਦ', 'ਛੋਟੇ_ਔਜ਼ਾਰ' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'Gadgets' => array( 'Gadżety' ),
);

/** Romanian (română) */
$specialPageAliases['ro'] = array(
	'Gadgets' => array( 'Gadgeturi' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Gadgets' => array( 'Гаджеты' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'Gadgets' => array( 'सुविधा_(गॅजेट)' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'Gadgets' => array( 'Accessori' ),
);

/** Sinhala (සිංහල) */
$specialPageAliases['si'] = array(
	'Gadgets' => array( 'විජෙට්ටු' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'Gadgets' => array( 'Hračky' ),
);

/** Slovenian (slovenščina) */
$specialPageAliases['sl'] = array(
	'Gadgets' => array( 'Vtičniki', 'Vticniki' ),
);

/** Serbian (Cyrillic script) (српски (ћирилица)‎) */
$specialPageAliases['sr-ec'] = array(
	'Gadgets' => array( 'Гаџети', 'Геџети' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'Gadgets' => array( 'Finesser' ),
);

/** Thai (ไทย) */
$specialPageAliases['th'] = array(
	'Gadgets' => array( 'อุปกรณ์เสริม', 'แกเจต' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Gadgets' => array( 'Mga_gadyet' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Gadgets' => array( 'KüçükAraçlar' ),
);

/** Tatar (Cyrillic script) (татарча) */
$specialPageAliases['tt-cyrl'] = array(
	'Gadgets' => array( 'Гаджетлар' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'Gadgets' => array( 'Додатки' ),
);

/** Venetian (vèneto) */
$specialPageAliases['vec'] = array(
	'Gadgets' => array( 'Strumenti' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Gadgets' => array( 'Tiện_ích', 'Công_cụ_đa_năng' ),
);

/** Chinese (中文) */
$specialPageAliases['zh'] = array(
	'Gadgets' => array( '小工具' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Gadgets' => array( '小工具' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Gadgets' => array( '小工具' ),
);

==> mediawiki-1.26.2-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/Gadgets/Gadgets.alias.php <==
<?php
/**
 * Aliases for Special:Gadgets
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Gadgets' => array( 'Gadgets' ),
);

/** Afrikaans (Afrikaans) */
$specialPageAliases['af'] = array(
	'Gadgets' => array( 'Geriewe' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Gadgets' => array( 'إضافات' ),
);

/** Egyptian Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Gadgets' => array( 'ادوات' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'Gadgets' => array( 'গেজেটসমূহ' ),
);

/** Avaric (авар) */
$specialPageAliases['av'] = array(
	'Gadgets' => array( 'Гаджеты' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'Gadgets' => array( 'Джаджи' ),
);

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = array(
	'Gadgets' => array( 'وسایل_ئان' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'Gadgets' => array( 'Pakakas' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'Gadgets' => array( 'Bitrakoù' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'Gadgets' => array( 'Dodaci' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'Gadgets' => array( 'Гаджеташ' ),
);

/** Central Kurdish (کوردیی ناوەندی) */
$specialPageAliases['ckb'] = array(
	'Gadgets' => array( 'ئامرازەکان' ),
);

/** Czech (čeština) */
$specialPageAliases['cs'] = array(
	'Gadgets' => array( 'Udělátka' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Gadgets' => array( 'Helferlein' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Gadgets' => array( 'Gadgeti' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'Gadgets' => array( 'Gadgety' ),
);

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = array(
	'Gadgets' => array( 'Εργαλεία', 'Προσαρτήματα' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Gadgets' => array( 'Aldonaĵoj' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Gadgets' => array( 'Accesorios', 'Artilugios' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Gadgets' => array( 'Tööriistad' ),
);

/** Basque (euskara) */
$specialPageAliases['eu'] = array(
	'Gadgets' => array( 'Gadgetak' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Gadgets' => array( 'ابزارها' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'Gadgets' => array( 'Pienoisohjelmat' ),
);

/** Arpitan (arpetan) */
$specialPageAliases['frp'] = array(
	'Gadgets' => array( 'Outils' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Gadgets' => array( 'Trebellos' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'Gadgets' => array( 'Hälferli' ),
);

/** Hawaiian (Hawai`i) */
$specialPageAliases['haw'] = array(
	'Gadgets' => array( 'Hāmeʻa', 'Hamea' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Gadgets' => array( 'גאדג\'טים', 'סקריפטים' ),
);

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = array(
	'Gadgets' => array( 'उपकरण', 'गैजेट' ),
);

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = array(
	'Gadgets' => array( 'Dodaci' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'Gadgets' => array( 'Specialne_funkcije' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Gadgets' => array( 'Gajèt' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Gadgets' => array( 'Segédeszközök' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'Gadgets' => array( 'Gadgetes' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Gadgets' => array( 'Alat', 'Gadget' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'Gadgets' => array( 'Accessori' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Gadgets' => array( 'ガジェット' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Gadgets' => array( '소도구', '가젯' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'Gadgets' => array( 'Instrumenticos' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'Gadgets' => array( 'Gadgeten' ),
);

/** Northern Luri (لۊری شومالی) */
$specialPageAliases['lrc'] = array(
	'Gadgets' => array( 'گأجئتیا' ),
);

/** Minangkabau (Baso Minangkabau) */
$specialPageAliases['min'] = array(
	'Gadgets' => array( 'Pakakeh' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Gadgets' => array( 'Алатки' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Gadgets' => array( 'കൂട' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'Gadgets' => array( 'सुविधा' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'Gadgets' => array( 'Gajet' ),
);

/** Maltese (Malti) */
$specialPageAliases['mt'] = array(
	'Gadgets' => array( 'Aġġeġġi', 'Aċċessorji' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'Gadgets' => array( 'Tilleggsfunksjoner' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'Gadgets' => array( 'Technies_spul' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'Gadgets' => array( 'Extensies' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'Gadgets' => array( 'Tilleggsfunksjonar' ),
);

/** Occitan (occitan) */
$specialPageAliases['oc'] = array(
	'Gadgets' => array( 'Gadgèts' ),
);

/** Punjabi (ਪੰਜਾਬੀ) */
$specialPageAliases['pa'] = array(
	'Gadgets' => array( 'ਛੋਟੇ_ਸੰਦ', 'ਛੋਟੇ_ਔਜ਼ਾਰ' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'Gadgets' => array( 'Gadżety' ),
);

/** Romanian (română) */
$specialPageAliases['ro'] = array(
	'Gadgets' => array( 'Gadgeturi' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Gadgets' => array( 'Гаджеты' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'Gadgets' => array( 'सुविधा_(गॅजेट)' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'Gadgets' => array( 'Accessori' ),
);

/** Sinhala (සිංහල) */
$specialPageAliases['si'] = array(
	'Gadgets' => array( 'විජෙට්ටු' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'Gadgets' => array( 'Hračky' ),
);

/** Slovenian (slovenščina) */
$specialPageAliases['sl'] = array(
	'Gadgets' => array( 'Vtičniki', 'Vticniki' ),
);

/** Serbian (Cyrillic script) (српски (ћирилица)‎) */
$specialPageAliases['sr-ec'] = array(
	'Gadgets' => array( 'Гаџети', 'Геџети' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'Gadgets' => array( 'Finesser' ),
);

/** Thai (ไทย) */
$specialPageAliases['th'] = array(
	'Gadgets' => array( 'อุปกรณ์เสริม', 'แกเจต' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Gadgets' => array( 'Mga_gadyet' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Gadgets' => array( 'KüçükAraçlar' ),
);

/** Tatar (Cyrillic script) (татарча) */
$specialPageAliases['tt-cyrl'] = array(
	'Gadgets' => array( 'Гаджетлар' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'Gadgets' => array( 'Додатки' ),
);

/** Venetian (vèneto) */
$specialPageAliases['vec'] = array(
	'Gadgets' => array( 'Strumenti' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Gadgets' => array( 'Tiện_ích', 'Công_cụ_đa_năng' ),
);

/** Chinese (中文) */
$specialPageAliases['zh'] = array(
	'Gadgets' => array( '小工具' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Gadgets' => array( '小工具' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Gadgets' => array( '小工具' ),
);
